@@ -40,14 +40,16 @@ void SelectedNotefolderDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), mySelectedNotefolderDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySelectedNotefolderDialogName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SelectedNotefolderDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), mySelectedNotefolderDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySelectedNotefolderDialogName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
+
+#include "moc_selectednotefolderdialog.cpp"
