@@ -55,6 +55,7 @@
 #include <QWindow>
 
 #if KDEPIM_HAVE_X11
+#include <KWindowInfo>
 #include <KX11Extras>
 #include <NETWM>
 #include <fixx11h.h>
@@ -594,10 +595,12 @@ void KNote::updateKeepAboveBelow(bool save)
 void KNote::slotUpdateShowInTaskbar()
 {
 #if KDEPIM_HAVE_X11
-    if (!mDisplayAttribute->showInTaskbar()) {
-        KWindowSystem::setState(winId(), KWindowInfo(winId(), NET::WMState).state() | NET::SkipTaskbar);
-    } else {
-        KWindowSystem::clearState(winId(), NET::SkipTaskbar);
+    if (KWindowSystem::isPlatformX11()) {
+        if (!mDisplayAttribute->showInTaskbar()) {
+            KX11Extras::setState(winId(), KWindowInfo(winId(), NET::WMState).state() | NET::SkipTaskbar);
+        } else {
+            KX11Extras::clearState(winId(), NET::SkipTaskbar);
+        }
     }
 #endif
 }
@@ -707,11 +710,7 @@ void KNote::createActions()
 #if KDEPIM_HAVE_X11
     m_toDesktop = new KSelectAction(i18n("To Desktop"), this);
     actionCollection()->addAction(QStringLiteral("to_desktop"), m_toDesktop);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(m_toDesktop, qOverload<QAction *>(&KSelectAction::triggered), this, &KNote::slotPopupActionToDesktop);
-#else
     connect(m_toDesktop, &KSelectAction::actionTriggered, this, &KNote::slotPopupActionToDesktop);
-#endif
     connect(m_toDesktop->menu(), &QMenu::aboutToShow, this, &KNote::slotUpdateDesktopActions);
     // initially populate it, otherwise stays disabled
     slotUpdateDesktopActions();
@@ -738,7 +737,7 @@ void KNote::createActions()
 void KNote::createNoteHeader()
 {
     // load style configuration
-    KConfigGroup styleGroup(m_kwinConf, "Style");
+    KConfigGroup styleGroup(m_kwinConf, QStringLiteral("Style"));
 
     QBoxLayout::Direction headerLayoutDirection = QBoxLayout::LeftToRight;
 
@@ -1131,22 +1130,14 @@ bool KNote::eventFilter(QObject *o, QEvent *ev)
         }
 
         if (ev->type() == QEvent::MouseMove && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            QPoint newPos = e->globalPos() - mOrigPos - QPoint(1, 1);
-#else
             QPoint newPos = e->globalPosition().toPoint() - mOrigPos - QPoint(1, 1);
-#endif
             move(newPos);
             return true;
         }
 
         if (ev->type() == QEvent::MouseButtonRelease
             && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            QPoint newPos = e->globalPos() - mOrigPos - QPoint(1, 1);
-#else
             QPoint newPos = e->globalPosition().toPoint() - mOrigPos - QPoint(1, 1);
-#endif
             move(newPos);
             return false;
         }
@@ -1186,3 +1177,5 @@ void KNote::slotDebugAkonadiSearch()
     dlg->doSearch();
     dlg->show();
 }
+
+#include "moc_knote.cpp"
